Struct snap::read::FrameDecoder [−][src]
pub struct FrameDecoder<R: Read> { /* fields omitted */ }
A reader for decompressing a Snappy stream.
This FrameDecoder wraps any other reader that implements std::io::Read.
Bytes read from this reader are decompressed using the
Snappy frame format
(file extension sz, MIME type application/x-snappy-framed).
This reader can potentially make many small reads from the underlying stream depending on its format, therefore, passing in a buffered reader may be beneficial.
Implementations
impl<R: Read> FrameDecoder<R>[src]
impl<R: Read> FrameDecoder<R>[src]pub fn new(rdr: R) -> FrameDecoder<R>ⓘNotable traits for FrameDecoder<R>
impl<R: Read> Read for FrameDecoder<R>[src]
Notable traits for FrameDecoder<R>
impl<R: Read> Read for FrameDecoder<R>Create a new reader for streaming Snappy decompression.
pub fn get_ref(&self) -> &R[src]
Gets a reference to the underlying reader in this decoder.
pub fn get_mut(&mut self) -> &mut R[src]
Gets a mutable reference to the underlying reader in this decoder.
Note that mutation of the stream may result in surprising results if this decoder is continued to be used.